@@ -42,6 +42,7 @@ public:
     QString previewCommand;
     QString parameters;
     QList<QString> defaultParameterValues;
+    QList<int> defaultVisibilityStates;
     QString hash;
     bool isAccurateIfZoomed;
     float previewFactor;
@@ -58,23 +59,27 @@ public:
   ~FiltersPresenter();
   void setFiltersView(FiltersView * filtersView);
   void rebuildFilterView();
-  void rebuildFilterViewWithSelection(QList<QString> keywords);
+  void rebuildFilterViewWithSelection(const QList<QString> & keywords);
 
   void clear();
   void readFilters();
   void readFaves();
+
+  bool allFavesAreValid() const;
+  bool danglingFaveIsSelected() const;
+
   /**
    * @brief restoreFaveHashLinksRelease236
    * Starting with release 240 of gmic, filter name capitalization has been normalized.
-   * For exemple : "Add grain" became "Add Grain"
+   * For example : "Add grain" became "Add Grain"
    * As a consequence, links between faves and filters based on hashes (computed in part
    * from the name) were broken.
    * This method tries to restore the links in the case when 4 faves or more are broken.
    */
-  void restoreFaveHashLinksRelease236();
+  void restoreFaveHashLinksAfterCaseChange();
   void importGmicGTKFaves();
   void saveFaves();
-  void addSelectedFilterAsNewFave(QList<QString> defaultValues, GmicQt::InputOutputState inOutState);
+  void addSelectedFilterAsNewFave(const QList<QString> & defaultValues, const QList<int> & visibilityStates, GmicQt::InputOutputState inOutState);
 
   void applySearchCriterion(const QString & text);
   void selectFilterFromHash(QString hash, bool notify);
@@ -93,6 +98,8 @@ public:
   void expandAll();
   void collapseAll();
 
+  const QString & errorMessage() const;
+
 signals:
   void filterSelectionChanged();
   void faveAdditionRequested(QString);
@@ -100,20 +107,21 @@ signals:
 public slots:
   void removeSelectedFave();
   void editSelectedFaveName();
-  void onFaveRenamed(QString hash, QString newName);
+  void onFaveRenamed(const QString & hash, const QString & name);
   void toggleSelectionMode(bool on);
 
 private slots:
-  void onFilterChanged(QString hash);
-  void removeFave(QString hash);
+  void onFilterChanged(const QString & hash);
+  void removeFave(const QString & hash);
 
 private:
-  void setCurrentFilter(QString hash);
+  void setCurrentFilter(const QString & hash);
 
   FiltersModel _filtersModel;
   FavesModel _favesModel;
   FiltersView * _filtersView;
   Filter _currentFilter;
+  QString _errorMessage;
 };
 
 #endif // _GMIC_QT_FILTERSPRESENTER_H_
