@@ -7,7 +7,7 @@
 <context>
     <name>ColorParameter</name>
     <message>
-        <location filename="../src/FilterParameters/ColorParameter.cpp" line="132"/>
+        <location filename="../src/FilterParameters/ColorParameter.cpp" line="133"/>
         <source>Select color</source>
         <translation>Pilih warna</translation>
     </message>
@@ -20,173 +20,198 @@
         <translation>Dialog</translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="102"/>
+        <location filename="../ui/dialogsettings.ui" line="221"/>
         <source>Internet updates</source>
         <translation>Pembaruan internet</translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="111"/>
+        <location filename="../ui/dialogsettings.ui" line="230"/>
         <source>Update now</source>
         <translation>Perbarui sekarang</translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="140"/>
+        <location filename="../ui/dialogsettings.ui" line="30"/>
         <source>Layout</source>
         <translation>Tata letak</translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="204"/>
+        <location filename="../ui/dialogsettings.ui" line="24"/>
+        <source>Interface</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ui/dialogsettings.ui" line="64"/>
         <source>Preview on the &amp;left</source>
         <translation>Tinjauan di &amp;kiri</translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="167"/>
+        <location filename="../ui/dialogsettings.ui" line="94"/>
         <source>Pre&amp;view on right side</source>
         <translation>Tinjauan di &amp;kanan</translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="24"/>
+        <location filename="../ui/dialogsettings.ui" line="113"/>
         <source>Theme</source>
         <translation>Tema</translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="30"/>
+        <location filename="../ui/dialogsettings.ui" line="119"/>
         <source>&amp;Default</source>
         <translation>&amp;Setelan standar</translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="37"/>
+        <location filename="../ui/dialogsettings.ui" line="126"/>
         <source>Dar&amp;k</source>
         <translation>&amp;Gelap</translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="50"/>
+        <location filename="../ui/dialogsettings.ui" line="139"/>
         <source>&lt;i&gt;(Restart needed)&lt;/I&gt;</source>
         <translation>&lt;i&gt;(Restart diperlukan)&lt;/i&gt;</translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="60"/>
+        <location filename="../ui/dialogsettings.ui" line="149"/>
         <source>Language</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="72"/>
-        <location filename="../src/DialogSettings.cpp" line="77"/>
+        <location filename="../ui/dialogsettings.ui" line="179"/>
+        <source>Always enable preview zooming</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ui/dialogsettings.ui" line="186"/>
+        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-style:italic;&quot;&gt;(Warning: preview may be inaccurate&lt;br/&gt;if checked.)&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ui/dialogsettings.ui" line="215"/>
+        <source>Other</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ui/dialogsettings.ui" line="253"/>
+        <location filename="../src/DialogSettings.cpp" line="84"/>
         <source>Output messages</source>
         <translation>Pesan-pesan keluaran</translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="84"/>
+        <location filename="../ui/dialogsettings.ui" line="196"/>
         <source>Dialogs</source>
         <translation>Dialog-dialog</translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="90"/>
+        <location filename="../ui/dialogsettings.ui" line="202"/>
         <source>Use native color dialog</source>
         <translation>Gunakan dialog warna native</translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="121"/>
+        <location filename="../ui/dialogsettings.ui" line="163"/>
         <source>Preview</source>
         <translation>Tinjauan</translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="127"/>
+        <location filename="../ui/dialogsettings.ui" line="169"/>
         <source>Timeout (seconds)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="176"/>
+        <location filename="../ui/dialogsettings.ui" line="36"/>
         <source>Show institution logos</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="240"/>
+        <location filename="../ui/dialogsettings.ui" line="262"/>
+        <source>Notify when scheduled update fails</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ui/dialogsettings.ui" line="304"/>
         <source>&amp;Ok</source>
         <translation>&amp;Ok</translation>
     </message>
     <message>
-        <location filename="../src/DialogSettings.cpp" line="57"/>
+        <location filename="../src/DialogSettings.cpp" line="64"/>
         <source>Settings</source>
         <translation>Setelan</translation>
     </message>
     <message>
-        <location filename="../src/DialogSettings.cpp" line="63"/>
+        <location filename="../src/DialogSettings.cpp" line="70"/>
         <source>Never</source>
         <translation>Tidak pernah</translation>
     </message>
     <message>
-        <location filename="../src/DialogSettings.cpp" line="64"/>
+        <location filename="../src/DialogSettings.cpp" line="71"/>
         <source>Daily</source>
         <translation>Harian</translation>
     </message>
     <message>
-        <location filename="../src/DialogSettings.cpp" line="65"/>
+        <location filename="../src/DialogSettings.cpp" line="72"/>
         <source>Weekly</source>
         <translation>Mingguan</translation>
     </message>
     <message>
-        <location filename="../src/DialogSettings.cpp" line="66"/>
+        <location filename="../src/DialogSettings.cpp" line="73"/>
         <source>Every 2 weeks</source>
         <translation>Tiap 2 minggu</translation>
     </message>
     <message>
-        <location filename="../src/DialogSettings.cpp" line="67"/>
+        <location filename="../src/DialogSettings.cpp" line="74"/>
         <source>Monthly</source>
         <translation>Bulanan</translation>
     </message>
     <message>
-        <location filename="../src/DialogSettings.cpp" line="69"/>
+        <location filename="../src/DialogSettings.cpp" line="76"/>
         <source>At launch (debug)</source>
         <translation>Pada pembukaan (debug)</translation>
     </message>
     <message>
-        <location filename="../src/DialogSettings.cpp" line="78"/>
+        <location filename="../src/DialogSettings.cpp" line="85"/>
         <source>Output messages...</source>
         <translation>Pesan-pesan keluaran...</translation>
     </message>
     <message>
-        <location filename="../src/DialogSettings.cpp" line="79"/>
+        <location filename="../src/DialogSettings.cpp" line="86"/>
         <source>Quiet (default)</source>
         <translation>Sunyi (setelan standar)</translation>
     </message>
     <message>
-        <location filename="../src/DialogSettings.cpp" line="80"/>
+        <location filename="../src/DialogSettings.cpp" line="87"/>
         <source>Verbose (layer name)</source>
         <translation>Verbose (nama lapisan)</translation>
     </message>
     <message>
-        <location filename="../src/DialogSettings.cpp" line="81"/>
+        <location filename="../src/DialogSettings.cpp" line="88"/>
         <source>Verbose (console)</source>
         <translation>Verbose (konsol)</translation>
     </message>
     <message>
-        <location filename="../src/DialogSettings.cpp" line="82"/>
+        <location filename="../src/DialogSettings.cpp" line="89"/>
         <source>Verbose (log file)</source>
         <translation>Verbose (berkas laporan)</translation>
     </message>
     <message>
-        <location filename="../src/DialogSettings.cpp" line="83"/>
+        <location filename="../src/DialogSettings.cpp" line="90"/>
         <source>Very verbose (console)</source>
         <translation>Very verbose (konsol)</translation>
     </message>
     <message>
-        <location filename="../src/DialogSettings.cpp" line="84"/>
+        <location filename="../src/DialogSettings.cpp" line="91"/>
         <source>Very verbose (log file)</source>
         <translation>Very verbose (berkas laporan)</translation>
     </message>
     <message>
-        <location filename="../src/DialogSettings.cpp" line="85"/>
+        <location filename="../src/DialogSettings.cpp" line="92"/>
         <source>Debug (console)</source>
         <translation>Debug (konsol)</translation>
     </message>
     <message>
-        <location filename="../src/DialogSettings.cpp" line="86"/>
+        <location filename="../src/DialogSettings.cpp" line="93"/>
         <source>Debug (log file)</source>
         <translation>Debug (berkas laporan)</translation>
     </message>
     <message>
-        <location filename="../src/DialogSettings.cpp" line="102"/>
+        <location filename="../src/DialogSettings.cpp" line="109"/>
         <source>Check to use Native/OS color dialog, uncheck to use Qt&apos;s</source>
         <translation>Centang untuk gunakan warna native, Tidak centang untuk gunakan Qt</translation>
     </message>
@@ -194,9 +219,9 @@
 <context>
     <name>FileParameter</name>
     <message>
-        <location filename="../src/FilterParameters/FileParameter.cpp" line="140"/>
-        <location filename="../src/FilterParameters/FileParameter.cpp" line="143"/>
-        <location filename="../src/FilterParameters/FileParameter.cpp" line="146"/>
+        <location filename="../src/FilterParameters/FileParameter.cpp" line="148"/>
+        <location filename="../src/FilterParameters/FileParameter.cpp" line="151"/>
+        <location filename="../src/FilterParameters/FileParameter.cpp" line="154"/>
         <source>Select a file</source>
         <translation>Pilih berkas</translation>
     </message>
@@ -204,24 +229,33 @@
 <context>
     <name>FilterParametersWidget</name>
     <message>
-        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="38"/>
-        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="147"/>
+        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="39"/>
+        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="172"/>
         <source>&lt;i&gt;Select a filter&lt;/i&gt;</source>
         <translation>&lt;i&gt;Pilih filter&lt;/i&gt;</translation>
     </message>
     <message>
-        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="116"/>
+        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="139"/>
         <source>&lt;i&gt;No parameters&lt;/i&gt;</source>
         <translation>&lt;i&gt;Tak ada parameter&lt;/i&gt;</translation>
     </message>
     <message>
-        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="121"/>
+        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="144"/>
         <source>Error parsing filter parameters
 
 </source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>FiltersPresenter</name>
+    <message>
+        <location filename="../src/FilterSelector/FiltersPresenter.cpp" line="411"/>
+        <source>Cannot find this fave&apos;s original filter
+</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>FiltersView</name>
     <message>
@@ -236,7 +270,7 @@
     </message>
     <message>
         <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="66"/>
-        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="332"/>
+        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="338"/>
         <source>Remove fave</source>
         <translation>Hapus favorit</translation>
     </message>
@@ -251,7 +285,7 @@
         <translation>Tambah favorit</translation>
     </message>
     <message>
-        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="332"/>
+        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="338"/>
         <source>Do you really want to remove the following fave?
 
 %1
@@ -262,7 +296,7 @@
 <context>
     <name>FolderParameter</name>
     <message>
-        <location filename="../src/FilterParameters/FolderParameter.cpp" line="118"/>
+        <location filename="../src/FilterParameters/FolderParameter.cpp" line="126"/>
         <source>Select a folder</source>
         <translation>Pilih folder</translation>
     </message>
@@ -293,136 +327,131 @@
         <translation type="unfinished">...</translation>
     </message>
     <message>
-        <location filename="../ui/inoutpanel.ui" line="112"/>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="44"/>
+        <location filename="../ui/inoutpanel.ui" line="102"/>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="45"/>
         <source>Input layers</source>
         <translation>Lapisan masukan</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="45"/>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="46"/>
         <source>None</source>
         <translation>Tidak ada</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="46"/>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="47"/>
         <source>Active (default)</source>
         <translation>Aktif (setelan standar)</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="47"/>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="48"/>
         <source>All</source>
         <translation>Semua</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="48"/>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="49"/>
         <source>Active and below</source>
         <translation>Aktif dan bawah</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="49"/>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="50"/>
         <source>Active and above</source>
         <translation>Aktif dan atas</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="50"/>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="51"/>
         <source>All visible</source>
         <translation>Semua terlihat</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="51"/>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="52"/>
         <source>All invisible</source>
         <translation>Semua tak terlihat</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="52"/>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="53"/>
         <source>All visible (decr.)</source>
         <translation>Semua terlihat (mengecil)</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="53"/>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="54"/>
         <source>All invisible (decr.)</source>
         <translation>Semua tak terlihat (mengecil)</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="54"/>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="55"/>
         <source>All (decr.)</source>
         <translation>Semua (mengecil)</translation>
     </message>
     <message>
-        <location filename="../ui/inoutpanel.ui" line="158"/>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="56"/>
+        <location filename="../ui/inoutpanel.ui" line="138"/>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="57"/>
         <source>Output mode</source>
         <translation>Modus keluaran</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="57"/>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="58"/>
         <source>In place (default)</source>
         <translation>Pada tempatnya (setelan standar)</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="58"/>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="59"/>
         <source>New layer(s)</source>
         <translation>Lapisan(-lapisan) baru</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="59"/>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="60"/>
         <source>New active layer(s)</source>
         <translation>Lapisan(-lapisan) aktif baru</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="60"/>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="61"/>
         <source>New image</source>
         <translation>Citra baru</translation>
     </message>
     <message>
-        <location filename="../ui/inoutpanel.ui" line="89"/>
-        <source>Output messages</source>
-        <translation>Pesan-pesan keluaran</translation>
-    </message>
-    <message>
-        <location filename="../ui/inoutpanel.ui" line="135"/>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="62"/>
+        <location filename="../ui/inoutpanel.ui" line="125"/>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="63"/>
         <source>Preview mode</source>
         <translation>Modus tinjauan</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="63"/>
-        <source>1st ouput (default)</source>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="64"/>
+        <source>1st output (default)</source>
         <translation>Keluaran pertama (setelan standar)</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="64"/>
-        <source>2nd ouput</source>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="65"/>
+        <source>2nd output</source>
         <translation type="unfinished">Keluaran ketiga {2c?}</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="67"/>
-        <source>1st -&gt; 2nd ouput</source>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="68"/>
+        <source>1st -&gt; 2nd output</source>
         <translation type="unfinished">Keluaran pertama -&gt; ketiga {1s?} {2c?}</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="65"/>
-        <source>3rd ouput</source>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="66"/>
+        <source>3rd output</source>
         <translation>Keluaran ketiga</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="66"/>
-        <source>4th ouput</source>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="67"/>
+        <source>4th output</source>
         <translation>Keluaran keempat</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="68"/>
-        <source>1st -&gt; 3rd ouput</source>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="69"/>
+        <source>1st -&gt; 3rd output</source>
         <translation>Keluaran pertama -&gt; ketiga</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="69"/>
-        <source>1st -&gt; 4th ouput</source>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="70"/>
+        <source>1st -&gt; 4th output</source>
         <translation>Keluaran pertama -&gt; keempat</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="70"/>
-        <source>All ouputs</source>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="71"/>
+        <source>All outputs</source>
         <translation>Semua keluaran</translation>
     </message>
 </context>
@@ -452,12 +481,12 @@
         <translation>GMIC</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="155"/>
+        <location filename="../ui/mainwindow.ui" line="161"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Download filter definitions from remote sources&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Scaricare le definizioni dei filtri da remoto&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="158"/>
+        <location filename="../ui/mainwindow.ui" line="164"/>
         <source>Internet</source>
         <translation>Internet</translation>
     </message>
@@ -467,70 +496,50 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="532"/>
+        <location filename="../ui/mainwindow.ui" line="489"/>
         <source>TextLabel</source>
         <translation>LabelTeks</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="227"/>
+        <location filename="../ui/mainwindow.ui" line="233"/>
         <source>...</source>
         <translation>...</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="370"/>
-        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Enable/disable preview&lt;br/&gt;(right click on preview image for instant swaping)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Abilitare/disabilitare anteprima&lt;br/&gt;(click destro per alternare)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
+        <location filename="../ui/mainwindow.ui" line="379"/>
+        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Enable/disable preview&lt;br/&gt;(Ctrl+P)&lt;br/&gt;(right click on preview image for instant swapping)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="373"/>
+        <location filename="../ui/mainwindow.ui" line="382"/>
         <source>Preview</source>
         <translation>Tinjauan</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="516"/>
+        <location filename="../ui/mainwindow.ui" line="473"/>
         <source>Settings...</source>
         <translation>Pengaturan...</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="545"/>
+        <location filename="../ui/mainwindow.ui" line="502"/>
         <source>&amp;Cancel</source>
         <translation>&amp;Batalkan</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="558"/>
+        <location filename="../ui/mainwindow.ui" line="515"/>
         <source>&amp;Fullscreen</source>
         <translation>&amp;Layar penuh</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="571"/>
+        <location filename="../ui/mainwindow.ui" line="528"/>
         <source>&amp;Apply</source>
         <translation>&amp;Terapkan</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="584"/>
+        <location filename="../ui/mainwindow.ui" line="541"/>
         <source>&amp;OK</source>
         <translation>&amp;Ok</translation>
     </message>
-    <message>
-        <location filename="../src/MainWindow.cpp" line="77"/>
-        <source>Zoom in</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/MainWindow.cpp" line="78"/>
-        <source>Zoom out</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/MainWindow.cpp" line="79"/>
-        <source>Reset zoom</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/MainWindow.cpp" line="81"/>
-        <source>Warning: Preview may be inaccurate (zoom factor has been modified)</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="82"/>
         <source>Add fave</source>
@@ -543,8 +552,8 @@
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="87"/>
-        <source>Update filters</source>
-        <translation>Perbarui filter</translation>
+        <source>Update filters (Ctrl+R / F5)</source>
+        <translation>Perbarui filter (Ctrl+R / F5)</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="89"/>
@@ -563,68 +572,73 @@
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="97"/>
-        <source>G&apos;MIC (http://gmic.eu)&lt;br/&gt;GREYC (http://www.greyc.fr)&lt;br/&gt;CNRS (http://www.cnrs.fr)&lt;br/&gt;Normandy University (http://www.unicaen.fr)&lt;br/&gt;Ensicaen (http://www.ensicaen.fr)</source>
-        <translation>G&apos;MIC (http://gmic.eu)&lt;br/&gt;GREYC (http://www.greyc.fr)&lt;br/&gt;CNRS (http://www.cnrs.fr)&lt;br/&gt;Normandie Université (http://www.unicaen.fr)&lt;br/&gt;Ensicaen (http://www.ensicaen.fr)</translation>
+        <source>G&apos;MIC (https://gmic.eu)&lt;br/&gt;GREYC (https://www.greyc.fr)&lt;br/&gt;CNRS (https://www.cnrs.fr)&lt;br/&gt;Normandy University (https://www.unicaen.fr)&lt;br/&gt;Ensicaen (https://www.ensicaen.fr)</source>
+        <translation>G&apos;MIC (https://gmic.eu)&lt;br/&gt;GREYC (https://www.greyc.fr)&lt;br/&gt;CNRS (https://www.cnrs.fr)&lt;br/&gt;Normandie Université (https://www.unicaen.fr)&lt;br/&gt;Ensicaen (https://www.ensicaen.fr)</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="263"/>
+        <location filename="../src/MainWindow.cpp" line="287"/>
         <source>Update completed</source>
         <translation>Pembaruan selesai</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="263"/>
-        <location filename="../src/MainWindow.cpp" line="265"/>
-        <location filename="../src/MainWindow.cpp" line="316"/>
+        <location filename="../src/MainWindow.cpp" line="287"/>
+        <location filename="../src/MainWindow.cpp" line="289"/>
+        <location filename="../src/MainWindow.cpp" line="343"/>
         <source>Filter definitions have been updated.</source>
         <translation>Definisi filter telah diperbarui.</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="268"/>
+        <location filename="../src/MainWindow.cpp" line="292"/>
         <source>No download was needed.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="447"/>
+        <location filename="../src/MainWindow.cpp" line="339"/>
+        <source>Filters update could not be achieved</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="461"/>
         <source>The update could not be achieved&lt;br&gt;because of the following errors:&lt;br&gt;</source>
         <translation>Pembaruan gagal&lt;br/&gt;karena error berikut:&lt;br/&gt;</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="453"/>
+        <location filename="../src/MainWindow.cpp" line="467"/>
         <source>Update error</source>
         <translation>Error pada pembaruan</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="596"/>
+        <location filename="../src/MainWindow.cpp" line="650"/>
         <source>Error</source>
         <translation>Error</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="675"/>
+        <location filename="../src/MainWindow.cpp" line="742"/>
         <source>Waiting for cancelled jobs...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="1004"/>
+        <location filename="../src/MainWindow.cpp" line="1078"/>
         <source>Import faves</source>
         <translation>Impor favorit</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="1004"/>
+        <location filename="../src/MainWindow.cpp" line="1078"/>
         <source>Do you want to import faves from file below?&lt;br/&gt;%1</source>
         <translation>Apa anda ingin mengimpor favorit dari berkas dibawah?&lt;br/&gt;%1</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="1007"/>
+        <location filename="../src/MainWindow.cpp" line="1081"/>
         <source>Don&apos;t ask again</source>
         <translation>Jangan tanya lagi</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="1096"/>
+        <location filename="../src/MainWindow.cpp" line="1193"/>
         <source>Confirmation</source>
         <translation>Konfirmasi</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="1096"/>
+        <location filename="../src/MainWindow.cpp" line="1193"/>
         <source>A gmic command is running.&lt;br&gt;Do you really want to close the plugin?</source>
         <translation>Perintah gmic tengah berjalan.&lt;br&gt;Apa anda benar ingin menutup plugin?</translation>
     </message>
@@ -656,7 +670,7 @@
     </message>
     <message>
         <location filename="../ui/progressinfowidget.ui" line="48"/>
-        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="46"/>
+        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="48"/>
         <source>Abort</source>
         <translation>Hentikan</translation>
     </message>
@@ -666,23 +680,23 @@
         <translation>LabelTeks</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="43"/>
+        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="45"/>
         <source>G&apos;MIC-Qt Plug-in progression</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="141"/>
+        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="143"/>
         <source>Updating filters...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="196"/>
-        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="209"/>
+        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="198"/>
+        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="211"/>
         <source>[Processing %1 | %2]</source>
         <translation>[Memproses %1 | %2]</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="211"/>
+        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="213"/>
         <source>[Processing %1]</source>
         <translation>[Memproses %1]</translation>
     </message>
@@ -706,17 +720,17 @@
         <translation>Batalkan</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="103"/>
+        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="134"/>
         <source>%1 seconds</source>
         <translation>%1 detik</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="113"/>
+        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="144"/>
         <source>[Processing %1 | %2]</source>
         <translation>[Memproses %1 | %2]</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="115"/>
+        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="146"/>
         <source>[Processing %1]</source>
         <translation>[Memproses %1]</translation>
     </message>
@@ -724,27 +738,27 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../src/Host/None/host_none.cpp" line="81"/>
+        <location filename="../src/Host/None/host_none.cpp" line="82"/>
         <source>Select an image to open...</source>
         <translation>Pilih citra untuk dibuka...</translation>
     </message>
     <message>
-        <location filename="../src/Host/None/host_none.cpp" line="81"/>
+        <location filename="../src/Host/None/host_none.cpp" line="82"/>
         <source>PNG &amp; JPG files (*.png *.jpeg *.jpg *.PNG *.JPEG *.JPG)</source>
         <translation>Files PNG &amp; JPG (*.png *.jpeg *.jpg *.PNG *.JPEG *.JPG)</translation>
     </message>
     <message>
-        <location filename="../src/Host/None/host_none.cpp" line="87"/>
+        <location filename="../src/Host/None/host_none.cpp" line="88"/>
         <source>Error</source>
         <translation>Error</translation>
     </message>
     <message>
-        <location filename="../src/Host/None/host_none.cpp" line="87"/>
+        <location filename="../src/Host/None/host_none.cpp" line="88"/>
         <source>Could not open file.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/Host/None/host_none.cpp" line="91"/>
+        <location filename="../src/Host/None/host_none.cpp" line="92"/>
         <source>Default image</source>
         <translation type="unfinished"></translation>
     </message>
@@ -767,12 +781,12 @@
         <translation>Bingkai</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/SearchFieldWidget.cpp" line="72"/>
+        <location filename="../src/Widgets/SearchFieldWidget.cpp" line="76"/>
         <source>Search</source>
         <translation>Cari</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/SearchFieldWidget.cpp" line="73"/>
+        <location filename="../src/Widgets/SearchFieldWidget.cpp" line="77"/>
         <source>Search in filters list (%1)</source>
         <translation>Cari di daftar filter (%1)</translation>
     </message>
@@ -780,32 +794,32 @@
 <context>
     <name>Updater</name>
     <message>
-        <location filename="../src/Updater.cpp" line="206"/>
+        <location filename="../src/Updater.cpp" line="208"/>
         <source>Could not read/decompress %1</source>
         <translation>Tak terbaca/dekompresi %1</translation>
     </message>
     <message>
-        <location filename="../src/Updater.cpp" line="197"/>
+        <location filename="../src/Updater.cpp" line="199"/>
         <source>Error downloading %1 (empty file?)</source>
         <translation>Error download %1 (berkas kosong?)</translation>
     </message>
     <message>
-        <location filename="../src/Updater.cpp" line="212"/>
+        <location filename="../src/Updater.cpp" line="214"/>
         <source>Error creating file %1</source>
         <translation>Error membuat berkas %1</translation>
     </message>
     <message>
-        <location filename="../src/Updater.cpp" line="216"/>
+        <location filename="../src/Updater.cpp" line="218"/>
         <source>Error writing file %1</source>
         <translation>Error menulis berkas %1</translation>
     </message>
     <message>
-        <location filename="../src/Updater.cpp" line="228"/>
-        <source>Error downloading %1</source>
-        <translation>Error mengunduh %1</translation>
+        <location filename="../src/Updater.cpp" line="235"/>
+        <source>Error downloading %1&lt;br/&gt;Error %2: %3</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/Updater.cpp" line="256"/>
+        <location filename="../src/Updater.cpp" line="268"/>
         <source>Download timeout: %1</source>
         <translation>Unduhan menunggu: %1</translation>
     </message>
@@ -813,9 +827,29 @@
 <context>
     <name>ZoomLevelSelector</name>
     <message>
-        <location filename="../ui/zoomlevelselector.ui" line="14"/>
+        <location filename="../ui/zoomlevelselector.ui" line="20"/>
         <source>Form</source>
         <translation>GMIC</translation>
     </message>
+    <message>
+        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="51"/>
+        <source>Zoom in</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="52"/>
+        <source>Zoom out</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="53"/>
+        <source>Reset zoom</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="153"/>
+        <source>Warning: Preview may be inaccurate (zoom factor has been modified)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
