@@ -12,7 +12,7 @@
  *
  * This software is a computer program whose purpose is to demonstrate
  * the possibilities of the GMIC image processing language by offering the
- * choice of several manipulations on a video stream aquired from a webcam. In
+ * choice of several manipulations on a video stream acquired from a webcam. In
  * other words, ZArt is a GUI for G'MIC real-time manipulations on the output
  * of a webcam.
  *
@@ -46,9 +46,9 @@
 #ifndef _CHOICEPARAMETER_H_
 #define _CHOICEPARAMETER_H_
 
-#include "AbstractParameter.h"
 #include <QDomNode>
 #include <QString>
+#include "AbstractParameter.h"
 class QComboBox;
 class QLabel;
 
@@ -57,21 +57,23 @@ class ChoiceParameter : public AbstractParameter {
 public:
   ChoiceParameter(QDomNode node, QObject * parent = 0);
   ~ChoiceParameter();
-  void addTo( QWidget *, int row );
+  void addTo(QWidget *, int row);
   QString textValue() const;
+  void setValue(const QString &);
   void reset();
   void saveValueInDOM();
 public slots:
   void onComboBoxIndexChanged(int);
 signals:
   void valueChanged();
+
 private:
   QDomNode _node;
   QString _name;
   int _default;
   int _value;
   QLabel * _label;
-  QComboBox* _comboBox;
+  QComboBox * _comboBox;
 };
 
 #endif // _CHOICEPARAMETER_H_
