@@ -12,7 +12,7 @@
  *
  * This software is a computer program whose purpose is to demonstrate
  * the possibilities of the GMIC image processing language by offering the
- * choice of several manipulations on a video stream aquired from a webcam. In
+ * choice of several manipulations on a video stream acquired from a webcam. In
  * other words, ZArt is a GUI for G'MIC real-time manipulations on the output
  * of a webcam.
  *
@@ -46,12 +46,12 @@
 #ifndef _COLORPARAMETER_H_
 #define _COLORPARAMETER_H_
 
-#include "AbstractParameter.h"
-#include <QDomNode>
-#include <QString>
 #include <QColor>
-#include <QPixmap>
 #include <QColorDialog>
+#include <QDomNode>
+#include <QPixmap>
+#include <QString>
+#include "AbstractParameter.h"
 class QSpinBox;
 class QSlider;
 class QLabel;
@@ -62,8 +62,9 @@ class ColorParameter : public AbstractParameter {
 public:
   ColorParameter(QDomNode node, QObject * parent = 0);
   ~ColorParameter();
-  void addTo( QWidget *, int row );
+  void addTo(QWidget *, int row);
   QString textValue() const;
+  void setValue(const QString & value);
   void reset();
   void saveValueInDOM();
 public slots:
@@ -71,8 +72,8 @@ public slots:
   void colorChanged(const QColor &);
 signals:
   void valueChanged();
-private:
 
+private:
   void updateButtonColor();
   QDomNode _node;
   QString _name;
