@@ -12,7 +12,7 @@
  *
  * This software is a computer program whose purpose is to demonstrate
  * the possibilities of the GMIC image processing language by offering the
- * choice of several manipulations on a video stream aquired from a webcam. In
+ * choice of several manipulations on a video stream acquired from a webcam. In
  * other words, ZArt is a GUI for G'MIC real-time manipulations on the output
  * of a webcam.
  *
@@ -46,33 +46,43 @@
 #ifndef _COMMANDPARAMSWIDGET_H_
 #define _COMMANDPARAMSWIDGET_H_
 
-#include <QWidget>
-#include <QVector>
 #include <QDomNode>
 #include <QPushButton>
+#include <QStringList>
+#include <QVector>
+#include <QWidget>
+#include "KeypointList.h"
+
 class AbstractParameter;
 class QLabel;
 
 class CommandParamsWidget : public QWidget {
   Q_OBJECT
 public:
-
   CommandParamsWidget(QWidget * parent = 0);
-  void build( QDomNode presetNode );
+  void build(QDomNode presetNode);
   virtual ~CommandParamsWidget();
   const QString & valueString() const;
+  QStringList valueStringList() const;
+  void setValues(const QStringList &);
   void saveValuesInDOM();
+  bool hasKeypoints() const;
+  KeypointList keypoints() const;
+  void setKeypoints(KeypointList list, bool notify);
+
 public slots:
   void updateValueString(bool notify = true);
   void reset();
 signals:
   void valueChanged();
+
 protected:
   void clear();
-  QVector<AbstractParameter*> _presetParameters;
+  QVector<AbstractParameter *> _presetParameters;
   QString _valueString;
   QPushButton * _pbReset;
   QLabel * _labelNoParams;
+  bool _hasKeypoints;
 };
 
 #endif // _COMMANDPARAMSWIDGET_H_
