@@ -12,7 +12,7 @@
  *
  * This software is a computer program whose purpose is to demonstrate
  * the possibilities of the GMIC image processing language by offering the
- * choice of several manipulations on a video stream aquired from a webcam. In
+ * choice of several manipulations on a video stream acquired from a webcam. In
  * other words, ZArt is a GUI for G'MIC real-time manipulations on the output
  * of a webcam.
  *
@@ -46,9 +46,9 @@
 #ifndef _FILEPARAMETER_H_
 #define _FILEPARAMETER_H_
 
-#include "AbstractParameter.h"
 #include <QDomNode>
 #include <QString>
+#include "AbstractParameter.h"
 class QLabel;
 class QPushButton;
 
@@ -57,14 +57,17 @@ class FileParameter : public AbstractParameter {
 public:
   FileParameter(QDomNode node, QObject * parent = 0);
   ~FileParameter();
-  void addTo( QWidget *, int row );
+  void addTo(QWidget *, int row);
   QString textValue() const;
+  QString unquotedTextValue() const;
+  void setValue(const QString & value);
   void reset();
   void saveValueInDOM();
 public slots:
   void onButtonPressed();
 signals:
   void valueChanged();
+
 private:
   QDomNode _node;
   QString _name;
