@@ -12,7 +12,7 @@
  *
  * This software is a computer program whose purpose is to demonstrate
  * the possibilities of the GMIC image processing language by offering the
- * choice of several manipulations on a video stream aquired from a webcam. In
+ * choice of several manipulations on a video stream acquired from a webcam. In
  * other words, ZArt is a GUI for G'MIC real-time manipulations on the output
  * of a webcam.
  *
@@ -46,9 +46,9 @@
 #ifndef _FLOATPARAMETER_H_
 #define _FLOATPARAMETER_H_
 
-#include "AbstractParameter.h"
 #include <QDomNode>
 #include <QString>
+#include "AbstractParameter.h"
 class QDoubleSpinBox;
 class QSlider;
 class QLabel;
@@ -58,8 +58,9 @@ class FloatParameter : public AbstractParameter {
 public:
   FloatParameter(QDomNode node, QObject * parent = 0);
   ~FloatParameter();
-  void addTo( QWidget *, int row );
+  void addTo(QWidget *, int row);
   QString textValue() const;
+  void setValue(const QString & value);
   void reset();
   void saveValueInDOM();
 public slots:
@@ -67,6 +68,7 @@ public slots:
   void onSpinBoxChanged(double);
 signals:
   void valueChanged();
+
 private:
   QDomNode _node;
   QString _name;
