@@ -12,7 +12,7 @@
  *
  * This software is a computer program whose purpose is to demonstrate
  * the possibilities of the GMIC image processing language by offering the
- * choice of several manipulations on a video stream aquired from a webcam. In
+ * choice of several manipulations on a video stream acquired from a webcam. In
  * other words, ZArt is a GUI for G'MIC real-time manipulations on the output
  * of a webcam.
  *
@@ -52,23 +52,29 @@ class ImageView;
 class MainWindow;
 class QShowEvent;
 class QFrame;
-class QTreeWidget;
+class QTreeView;
+class QAbstractItemModel;
+class QComboBox;
 
 class FullScreenWidget : public QWidget, public Ui::FullScreenWidget {
   Q_OBJECT
 public:
-  FullScreenWidget( MainWindow * );
+  FullScreenWidget(MainWindow *);
   ~FullScreenWidget();
   ImageView * imageView();
   QTreeWidget * treeWidget();
   CommandParamsWidget * commandParamsWidget();
+  void setFavesModel(QAbstractItemModel *);
+  QComboBox * cbFaves();
+
 protected:
   void showEvent(QShowEvent * event);
-  void mouseMoveEvent(QMouseEvent * event);
-  void keyPressEvent( QKeyEvent * );
+  void keyPressEvent(QKeyEvent *);
+  bool eventFilter(QObject * watched, QEvent * event);
 signals:
   void escapePressed();
   void spaceBarPressed();
+
 private:
   MainWindow * _mainWindow;
 };
