@@ -12,7 +12,7 @@
  *
  * This software is a computer program whose purpose is to demonstrate
  * the possibilities of the GMIC image processing language by offering the
- * choice of several manipulations on a video stream aquired from a webcam. In
+ * choice of several manipulations on a video stream acquired from a webcam. In
  * other words, ZArt is a GUI for G'MIC real-time manipulations on the output
  * of a webcam.
  *
@@ -46,8 +46,8 @@
 #ifndef _LINKPARAMETER_H_
 #define _LINKPARAMETER_H_
 
-#include "AbstractParameter.h"
 #include <Qt>
+#include "AbstractParameter.h"
 class QLabel;
 
 class LinkParameter : public AbstractParameter {
@@ -55,14 +55,16 @@ class LinkParameter : public AbstractParameter {
 public:
   LinkParameter(QDomNode node, QObject * parent = 0);
   ~LinkParameter();
-  void addTo( QWidget *, int row );
+  void addTo(QWidget *, int row);
   QString textValue() const;
+  void setValue(const QString & value);
   void reset();
   void saveValueInDOM();
 public slots:
   void onLinkActivated(const QString & link);
 signals:
   void valueChanged();
+
 private:
   QLabel * _label;
   QString _text;
