@@ -12,7 +12,7 @@
  *
  * This software is a computer program whose purpose is to demonstrate
  * the possibilities of the GMIC image processing language by offering the
- * choice of several manipulations on a video stream aquired from a webcam. In
+ * choice of several manipulations on a video stream acquired from a webcam. In
  * other words, ZArt is a GUI for G'MIC real-time manipulations on the output
  * of a webcam.
  *
@@ -54,12 +54,14 @@ class SeparatorParameter : public AbstractParameter {
 public:
   SeparatorParameter(QDomNode node, QObject * parent = 0);
   ~SeparatorParameter();
-  void addTo( QWidget *, int row );
+  void addTo(QWidget *, int row);
   QString textValue() const;
+  void setValue(const QString & value);
   void reset();
   void saveValueInDOM();
 signals:
   void valueChanged();
+
 private:
   QFrame * _frame;
 };
