@@ -12,7 +12,7 @@
  *
  * This software is a computer program whose purpose is to demonstrate
  * the possibilities of the GMIC image processing language by offering the
- * choice of several manipulations on a video stream aquired from a webcam. In
+ * choice of several manipulations on a video stream acquired from a webcam. In
  * other words, ZArt is a GUI for G'MIC real-time manipulations on the output
  * of a webcam.
  *
@@ -48,17 +48,21 @@
 #ifndef _TREEWIDGETPRESETITEM_H_
 #define _TREEWIDGETPRESETITEM_H_
 
+#include <QDomNode>
+#include <QStringList>
 #include <QTreeWidget>
 #include <QTreeWidgetItem>
-#include <QDomNode>
 
 class TreeWidgetPresetItem : public QTreeWidgetItem {
 public:
-  TreeWidgetPresetItem(const QStringList & strings, QDomNode node = QDomNode() );
-  TreeWidgetPresetItem(QTreeWidget * parent, const QStringList & strings, QDomNode node = QDomNode() );
-  TreeWidgetPresetItem(QTreeWidgetItem * parent, const QStringList & strings, QDomNode node = QDomNode() );
+  TreeWidgetPresetItem(const QStringList & strings, QDomNode node = QDomNode());
+  TreeWidgetPresetItem(QTreeWidget * parent, const QStringList & strings, QDomNode node = QDomNode());
+  TreeWidgetPresetItem(QTreeWidgetItem * parent, const QStringList & strings, QDomNode node = QDomNode());
   ~TreeWidgetPresetItem();
   QDomNode node() const;
+  TreeWidgetPresetItem * clone() const;
+  QStringList path() const;
+
 private:
   QDomNode _presetNode;
 };
