@@ -12,7 +12,7 @@
  *
  * This software is a computer program whose purpose is to demonstrate
  * the possibilities of the GMIC image processing language by offering the
- * choice of several manipulations on a video stream aquired from a webcam. In
+ * choice of several manipulations on a video stream acquired from a webcam. In
  * other words, ZArt is a GUI for G'MIC real-time manipulations on the output
  * of a webcam.
  *
@@ -47,14 +47,8 @@
 #ifndef _VIDEOFILESOURCE_H_
 #define _VIDEOFILESOURCE_H_
 
-#if defined(HAS_OPENCV2_HEADERS) || defined(OPENCV2_HEADERS)
-#include <opencv2/core/core_c.h>
-#include <opencv2/highgui/highgui_c.h>
-#else
-#include <cv.h>
-#include <highgui.h>
-#endif
 #include <QString>
+#include <opencv2/opencv.hpp>
 #include "ImageSource.h"
 
 class VideoFileSource : public ImageSource {
@@ -66,8 +60,9 @@ public:
   const QString & filename() const;
   const QString & filePath() const;
   void setLoop(bool);
+
 private:
-  CvCapture * _capture;
+  cv::VideoCapture * _capture;
   QString _filename;
   QString _filePath;
   bool _videoIsReadable;
